Deleting posts
==============

.. admonition:: Permissions

   You need the “can edit others’ posts” permission to delete posts of other
   users.  You can always delete your own posts.

Clicking on the red *Delete* button under a post will delete the post after
confirming with the user.

.. warning::

    Deleting a post is **permanent**.
